#
# spec file for package python-catkin-pkg
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%define commands create_pkg find_pkg generate_changelog package_version prepare_release tag_changelog test_changelog
Name:           python-catkin-pkg
Version:        1.0.0
Release:        2.1
Summary:        Catkin package library
License:        BSD-3-Clause
URL:            https://wiki.ros.org/catkin_pkg
Source0:        https://github.com/ros-infrastructure/catkin_pkg/archive/%{version}.tar.gz
Source99:       python-catkin-pkg.rpmlintrc
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-docutils
Requires:       python-pyparsing
Requires:       python-python-dateutil
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
# /SECTION
%python_subpackages

%description
Library for retrieving information about catkin packages.

%prep
%autosetup -p1 -n catkin_pkg-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
for c in %{commands}; do
  %python_clone -a %{buildroot}%{_bindir}/catkin_$c
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=$PWD/src
# flake8 line length checks failing (E501)
%pytest -k 'not test_flake8'

%pre
# If libalternatives is used: Removing old update-alternatives entries.
for c in %{commands}; do
  %python_libalternatives_reset_alternative catkin_$c
done

# post and postun macro call is not needed with only libalternatives

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/catkin_create_pkg
%python_alternative %{_bindir}/catkin_find_pkg
%python_alternative %{_bindir}/catkin_generate_changelog
%python_alternative %{_bindir}/catkin_package_version
%python_alternative %{_bindir}/catkin_prepare_release
%python_alternative %{_bindir}/catkin_tag_changelog
%python_alternative %{_bindir}/catkin_test_changelog
%{python_sitelib}/catkin_pkg
%{python_sitelib}/catkin_pkg*-info

%changelog
* Wed Jun  4 2025 Nico Krapp <nico.krapp@suse.com>
- fix usage of libalternatives
* Thu May 15 2025 Matej Cepl <mcepl@cepl.eu>
- Add missing rpmlintrc to the SPEC file.
* Thu May 15 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Dec 14 2023 pgajdos@suse.com
- deleted patches
  - python-catkin-pkg-no-mock.patch (upstreamed)
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 1.0.0:
  * List 'ROS Infrastructure Team' as the package maintainer.
    `#328 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/328>`_
  * Drop support for Python 2. `#354 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/354>`_
  * Move flake8 config to setup.cfg, address flake8 v6
    violations. `#356 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/356>`_
  * Contributors
  * Scott K Logan
  * Steven! Ragnarök
  * 0.5.2 (2022-05-27)
  * Use renamed function for getting multiple build types. `#342
    <https://github.com/ros-infrastructure/catkin_pkg/pull/342>`_
  * Resolves `#341 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/341>`_
  * Contributors
  * Steven! Ragnarök
  * 0.5.1 (2022-05-10)
  * Add API method for getting all build types regardless of
    conditions. `#337 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/337>`_
  * Pass all string format arguments as a tuple. `#339
    <https://github.com/ros-infrastructure/catkin_pkg/pull/339>`_
  * Resolves `#338 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/338>`_
  * Consider all build types when updating package versions.
    `#340 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/340>`_
  * Resolves `#336 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/336>`_
  * Contributors
  * Scott K Logan
  * Steven! Ragnarök
  * 0.5.0 (2022-05-10)
  * Remove references to Travis CI. `#314
    <https://github.com/ros-infrastructure/catkin_pkg/pull/314>`_
  * Drop python 2.7 on macOS. `#318 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/318>`_
  * Update release suites. `#317 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/317>`_
  * Use unittest.mock where possible. `#321
    <https://github.com/ros-infrastructure/catkin_pkg/pull/321>`_
  * Declare test dependencies in extras_require.test. `#323
    <https://github.com/ros-infrastructure/catkin_pkg/pull/323>`_
  * Drop support for Python < 2.7 (2.7 itself is still
    supported). `#322 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/322>`_
  * Run tests with pytest instead of nose. `#324
    <https://github.com/ros-infrastructure/catkin_pkg/pull/324>`_
  * Enable Python 3.10 tests, bump actions/setup-python. `#325
    <https://github.com/ros-infrastructure/catkin_pkg/pull/325>`_
  * Mark linter test and declare cov/junit module name. `#327
    <https://github.com/ros-infrastructure/catkin_pkg/pull/327>`_
  * Add plaintext_description field to Package. `#305
    <https://github.com/ros-infrastructure/catkin_pkg/pull/305>`_
  * Use only first line of plaintext description in distutils
    setup generation. `#326 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/326>`_
  * Update catkin_prepare_release to support setup.py files in
    ament_python packages. `#331 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/331>`_
  * This pull requests introduces an API change!
  * ``catkin_pkg.package_version.update_packages`` now takes the
    full dict of package Paths: Package objects instead of just
    the paths.
  * Make filenames to be used as ignore markers configurable.
    `#307 <https://github.com/ros-
    infrastructure/catkin_pkg/pull/307>`_
  * Fix catkin_package_version after API change. `#333
    <https://github.com/ros-infrastructure/catkin_pkg/pull/333>`_
  * Contributors
  * Jan Strohbeck
  * Scott K Logan
  * Steven! Ragnarök
  * Tomáš Hrnčiar
  * William Woodall
* Wed Mar  9 2022 pgajdos@suse.com
- do not require mock for build
- added patches
  https://github.com/ros-infrastructure/catkin_pkg/commit/b5c6812b40fa31da91ee560dda7c6e470dedcfb8
  + python-catkin-pkg-no-mock.patch
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.24:
  * stop using undocumented docutils api
  * remove validate_metapacakge wrapper
  * flake8 warnings
  * test fixes
  * add option to show only merge commits
  * compare dependencies with all attributes
* Wed Jul 29 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.22:
  * catkin_generate_changelog: hack to allow tag version prefixed with v
  * add GitLab auto linking for issues in catkin_generate_changelog
  * enable releasing from Focal with stdeb 0.9.1
  * fix deprecation warnings in tests
  * pass stricter pycodestyle 2.6 checks
  * Restore compatibility with pyparsing < 1.5.7
  * Respect (AMENT|COLCON|CATKIN)_IGNORE directories
  * bump min CMake version to avoid CMP0048 warning
  * Fix travis warning
  * use parse actions to evaluate conditions
  * Speed up topological_order by using a per-package cache of all run_depends
  * Fix crash with pyparsing 3
  * [enhancement]evaluating more than 1 condition fixes #277
  * exclude Signed-off-by: lines from changelog
  * Changes 'install' to 'catkin_install_python' in the CMakeLists.txt template
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
- use %%pytest
* Mon Mar 30 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.4.16
  * add Python 3.7 and 3.8 to Travis matrix
  * allow different CMake minimum version in metapackage
* Fri Jan 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.4.15
  * small fixes
* Sat Aug  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.13:
  * small fixes
- Fix download url
* Thu Jul 11 2019 Andreas Färber <afaerber@suse.de>
- Initial (v0.4.12)
